==> qtjambi-qt3drender-6.2.1-sources.jar: io/qt/qt3d/render/QLineWidth.java <==
package io.qt.qt3d.render;


/**
 * <p>Specifies the width of rasterized lines</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3drender-qlinewidth.html">Qt3DRender::QLineWidth</a></p>
 */
public class QLineWidth extends io.qt.qt3d.render.QRenderState
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QLineWidth.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qlinewidth.html#smooth-prop">Qt3DRender::QLineWidth::smoothChanged(bool)</a></p>
     */
    @io.qt.QtPropertyNotify(name="smooth")
    public final Signal1<@io.qt.QtPrimitiveType Boolean> smoothChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qlinewidth.html#value-prop">Qt3DRender::QLineWidth::valueChanged(float)</a></p>
     */
    @io.qt.QtPropertyNotify(name="value")
    public final Signal1<@io.qt.QtPrimitiveType Float> valueChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QLineWidth(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QLineWidth() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QLineWidth(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QLineWidth instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qlinewidth.html#smooth-prop">Qt3DRender::QLineWidth::setSmooth(bool)</a></p>
     */
    @io.qt.QtPropertyWriter(name="smooth")
    public final void setSmooth(boolean enabled){
        setSmooth_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), enabled);
    }
    
    private native void setSmooth_native_bool(long __this__nativeId, boolean enabled);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qlinewidth.html#value-prop">Qt3DRender::QLineWidth::setValue(float)</a></p>
     */
    @io.qt.QtPropertyWriter(name="value")
    public final void setValue(float value){
        setValue_native_float(QtJambi_LibraryUtilities.internal.nativeId(this), value);
    }
    
    private native void setValue_native_float(long __this__nativeId, float value);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qlinewidth.html#smooth-prop">Qt3DRender::QLineWidth::smooth()const</a></p>
     */
    @io.qt.QtPropertyReader(name="smooth")
    @io.qt.QtUninvokable
    public final boolean smooth(){
        return smooth_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean smooth_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qlinewidth.html#value-prop">Qt3DRender::QLineWidth::value()const</a></p>
     */
    @io.qt.QtPropertyReader(name="value")
    @io.qt.QtUninvokable
    public final float value(){
        return value_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native float value_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QLineWidth(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QLineWidth(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QLineWidth instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-6.4.0-sources.jar: io/qt/qt3d/render/QLineWidth.java <==
package io.qt.qt3d.render;


/**
 * <p>Specifies the width of rasterized lines</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qt3drender-qlinewidth.html">Qt3DRender::QLineWidth</a></p>
 */
public class QLineWidth extends io.qt.qt3d.render.QRenderState
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QLineWidth.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qlinewidth.html#smooth-prop">Qt3DRender::QLineWidth::smoothChanged(bool)</a></p>
     */
    @io.qt.QtPropertyNotify(name="smooth")
    public final Signal1<@io.qt.QtPrimitiveType Boolean> smoothChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qlinewidth.html#value-prop">Qt3DRender::QLineWidth::valueChanged(float)</a></p>
     */
    @io.qt.QtPropertyNotify(name="value")
    public final Signal1<@io.qt.QtPrimitiveType Float> valueChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QLineWidth(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QLineWidth() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QLineWidth(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QLineWidth instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qlinewidth.html#smooth-prop">Qt3DRender::QLineWidth::setSmooth(bool)</a></p>
     */
    @io.qt.QtPropertyWriter(name="smooth")
    public final void setSmooth(boolean enabled){
        setSmooth_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), enabled);
    }
    
    private native void setSmooth_native_bool(long __this__nativeId, boolean enabled);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qlinewidth.html#value-prop">Qt3DRender::QLineWidth::setValue(float)</a></p>
     */
    @io.qt.QtPropertyWriter(name="value")
    public final void setValue(float value){
        setValue_native_float(QtJambi_LibraryUtilities.internal.nativeId(this), value);
    }
    
    private native void setValue_native_float(long __this__nativeId, float value);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qlinewidth.html#smooth-prop">Qt3DRender::QLineWidth::smooth()const</a></p>
     */
    @io.qt.QtPropertyReader(name="smooth")
    @io.qt.QtUninvokable
    public final boolean smooth(){
        return smooth_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean smooth_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qlinewidth.html#value-prop">Qt3DRender::QLineWidth::value()const</a></p>
     */
    @io.qt.QtPropertyReader(name="value")
    @io.qt.QtUninvokable
    public final float value(){
        return value_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native float value_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QLineWidth(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QLineWidth(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QLineWidth instance, QDeclarativeConstructor constructor);
    
}
